@@ -14,7 +14,7 @@ def check_and_create_config(default_config_path,config_path):
             if not os.path.exists(os.path.dirname(config_path)):
                 os.mkdir(os.path.dirname(config_path))
             shutil.copyfile(default_config_path,config_path)
-            print >> sys.stderr, "Done.  Before proceeding, please edit {0}".format(config_path)
+            print >> sys.stderr, "Exiting.  Before proceeding, please edit {0}".format(config_path)
         sys.exit(1)
         # Creating settings dictionary
     return ConfigObj(config_path)
\ No newline at end of file
